@@ -5,13 +5,9 @@ a websocket client and a rest interface client
 
 # pylint: disable-all
 
-import asyncio
-
 from .websockets.bfx_websocket import BfxWebsocket
 from .rest.bfx_rest import BfxRest
-
-REST_HOST = 'https://api-pub.bitfinex.com/v2'
-WS_HOST = 'wss://api-pub.bitfinex.com/ws/2'
+from .constants import *
 
 class Client:
     """
