@@ -10,7 +10,7 @@ class WithdrawModel:
     METHOD = 2
     WALLET = 4
     AMOUNT = 5
-    FEE = 7
+    FEE = 8
 
 class Withdraw:
     """
@@ -42,7 +42,8 @@ class Withdraw:
         method = raw_withdraw[WithdrawModel.METHOD]
         wallet = raw_withdraw[WithdrawModel.WALLET]
         amount = raw_withdraw[WithdrawModel.AMOUNT]
-        return Withdraw(w_id, method, wallet, amount)
+        fee = raw_withdraw[WithdrawModel.FEE]
+        return Withdraw(w_id, method, wallet, amount, fee)
 
     def __str__(self):
         """
