@@ -43,6 +43,8 @@ class OrderManager:
         order.set_open_state(False)
         if order.id in self.open_orders:
             del self.open_orders[order.id]
+        if order.cid in self.pending_orders:
+            del self.pending_orders[order.cid]
         self.closed_orders[order.id] = order
         if not order.is_confirmed():
             order.set_confirmed()
@@ -78,8 +80,8 @@ class OrderManager:
     async def confirm_order_new(self, raw_ws_data):
         order = Order.from_raw_order(raw_ws_data[2])
         order.set_open_state(True)
-        if order.id in self.pending_orders:
-            del self.pending_orders[order.id]
+        if order.cid in self.pending_orders:
+            del self.pending_orders[order.cid]
         self.open_orders[order.id] = order
         order.set_confirmed()
         self.bfxapi._emit('order_confirmed', order)
@@ -87,6 +89,12 @@ class OrderManager:
         self.logger.info("Order new: {}".format(order))
         self.bfxapi._emit('order_new', order)
 
+    async def confirm_order_error(self, raw_ws_data):
+        cid = raw_ws_data[2][4][2]
+        if cid in self.pending_orders:
+            del self.pending_orders[cid]
+        self.logger.info("Deleted Order CID {} from pending orders".format(cid))
+
     async def submit_order(self, symbol, price, amount, market_type=Order.Type.LIMIT,
                            hidden=False, price_trailing=None, price_aux_limit=None,
                            oco_stop_price=None, close=False, reduce_only=False,
@@ -194,7 +202,7 @@ class OrderManager:
         if price_trailing != None:
             payload['price_trailing'] = str(price_trailing)
         if time_in_force != None:
-            payload['time_in_force'] = str(time_in_force)
+            payload['tif'] = str(time_in_force)
         if leverage != None:
             payload['lev'] = str(leverage)
         flags = calculate_order_flags(
